@@ -19,6 +19,8 @@ class ConfigSchema(TypedDict, total=False):
     default_resource: str
     last_update_check: Optional[datetime]
     servers: MutableMapping[str, ServerConfigSchema]
+    autoupdate: Optional[str]
+    analytics: Optional[str]
 
 
 class Config(ConfigBase[ConfigSchema]):
@@ -90,7 +92,7 @@ class Config(ConfigBase[ConfigSchema]):
     @classmethod
     @fail_ok
     def add_instance_alias(cls, instance: str, *, alias: str, region: str):
-        if (old_instance := cls.find_instance_by_alias(alias)) :
+        if old_instance := cls.find_instance_by_alias(alias):
             with cls._atomic_instance_mutation(old_instance) as instance_config:
                 instance_config["aliases"].remove(alias)
 
