@@ -45,12 +45,12 @@ class Saml2Aws(SAMLClient):
     )
 
     resource: str
-    options: "GlobalOptionsBase"
+    options: "GlobalOptions"
     config_file: Final[SymConfigFile]
     _config: Optional[ConfigParser]
     _s2a_options: Final[Options]
 
-    def __init__(self, resource: str, *, options: "GlobalOptionsBase") -> None:
+    def __init__(self, resource: str, *, options: "GlobalOptions") -> None:
         super().__init__(resource, options=options)
         self.config_file = SymConfigFile(resource=resource, file_name="saml2aws.cfg")
         self._s2a_options = {
@@ -58,6 +58,7 @@ class Saml2Aws(SAMLClient):
             "config": str(self.config_file),
             "idp_account": self._section_name,
             "skip_prompt": True,
+            "cache_saml": True,
         }
 
     def _check_version(self) -> bool:
@@ -102,7 +103,6 @@ class Saml2Aws(SAMLClient):
     def _saml2aws_envs(self) -> dict:
         return {
             "AWS_REGION": self.ensure_config()[self._section_name]["region"],
-            "SAML2AWS_CACHE_SAML": "true",
         }
 
     @intercept_errors(ErrorPatterns)
@@ -129,8 +129,12 @@ class Saml2Aws(SAMLClient):
             options = {**self._s2a_options, "skip_prompt": False}
             args = {"username": Config.get_email()}
         else:
-            options = self._s2a_options
+            options = {**self._s2a_options}
             args = {}
+
+        if force or self.options.disable_caches or not self.has_creds():
+            options["cache_saml"] = False
+
         with push_envs(self._saml2aws_envs()):
             # no-op if session active when force=False
             yield "saml2aws", options, "login", args, {"force": force}
