@@ -62,7 +62,7 @@ def test_ssh(ssh_tester, capture_command: CaptureCommand):
         capture_command.assert_command(
             ["exec", "true"],
             ["ssh-keygen"],
-            ["ssh", INSTANCE_ID, "-o BatchMode=yes"],
+            ["ssh", INSTANCE_ID, "-o", "BatchMode=yes"],
             ["ssh", INSTANCE_ID],
         )
 
@@ -77,7 +77,7 @@ def test_ssh_with_key(
     with ssh_tester(setup=setup):
         capture_command.assert_command(
             ["exec", "true"],
-            ["ssh", INSTANCE_ID, "-o BatchMode=yes"],
+            ["ssh", INSTANCE_ID, "-o", "BatchMode=yes"],
             ["ssh", INSTANCE_ID],
         )
 
@@ -97,7 +97,7 @@ def test_ssh_needs_put(uuid, ssh_tester, capture_command: CaptureCommand):
         capture_command.assert_command(
             ["exec", "true"],
             ["ssh-keygen"],
-            ["ssh", INSTANCE_ID, "-o BatchMode=yes"],
+            ["ssh", INSTANCE_ID, "-o", "BatchMode=yes"],
             ["ssh", INSTANCE_ID],
         )
 
@@ -116,7 +116,7 @@ def test_ssh_unknown_error(ssh_tester, capture_command: CaptureCommand):
         capture_command.assert_command(
             ["exec", "true"],
             ["ssh-keygen"],
-            ["ssh", INSTANCE_ID, "-o BatchMode=yes"],
+            ["ssh", INSTANCE_ID, "-o", "BatchMode=yes"],
         )
 
         expect(result.output).to(equal("Random Error"))
