@@ -2,7 +2,7 @@ import pytest
 from botocore.exceptions import ClientError
 from botocore.paginate import Paginator
 
-from sym.cli.errors import BotoError
+from sym.cli.errors import BotoError, ExpiredCredentials
 from sym.cli.helpers.boto import send_ssh_key
 from sym.cli.helpers.config import SymConfigFile
 from sym.cli.helpers.ec2.client import Ec2Client
@@ -45,7 +45,7 @@ def test_error_handling_expired(monkeypatch, boto_stub, click_context, saml_clie
     monkeypatch.setattr(Paginator, "paginate", paginate)
 
     with click_context:
-        with pytest.raises(BotoError, match="Your AWS credentials have expired."):
+        with pytest.raises(ExpiredCredentials):
             Ec2Client(saml_client).load_instance_by_alias("localhost")
 
 
