@@ -1,4 +1,5 @@
-from sym.cli.helpers.os import has_command
+from sym.shared.cli.helpers.os import has_command
+
 from sym.cli.tests.helpers.sandbox import Sandbox
 
 
