@@ -8,7 +8,7 @@ import pytest
 from semver import VersionInfo
 from sym.shared.cli.helpers.updater import FAIL_LOG_PATH
 
-from sym.cli.helpers.config import SymConfigFile
+from sym.cli.helpers.config import Config, SymConfigFile
 
 V1 = VersionInfo.parse("0.0.1")
 
@@ -51,6 +51,11 @@ def test_checks_first_time(pipx_updater):
     assert pipx_updater.should_check() == True
 
 
+def test_checks_first_time_no_autoupdate(pipx_updater):
+    Config.instance()["autoupdate"] = "false"
+    assert pipx_updater.should_check() == False
+
+
 def test_no_check_second_time(pipx_updater):
     assert pipx_updater.should_check() == True
     assert pipx_updater.should_check() == False
